==> tool-sql-2.2.0-sources.jar: ooaofooa/datatypes/ElementTypeConstants.java <==
package ooaofooa.datatypes;


import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.IXtumlType;


public enum ElementTypeConstants implements IXtumlType<ElementTypeConstants> {

    UNINITIALIZED_ENUM( -1 ),
    ACTIVITY_EDGE( 11 ),
    ACTIVITY_NODE( 17 ),
    ACTIVITY_PARTITION( 10 ),
    ASSOCIATION( 8 ),
    CLASS( 1 ),
    COMPONENT( 3 ),
    COMPONENT_REFERENCE( 20 ),
    CONSTANT( 9 ),
    DATATYPE( 2 ),
    DELEGATION( 22 ),
    EE( 4 ),
    EXCEPTION( 23 ),
    FUNCTION( 0 ),
    IMPORTED_CLASS( 18 ),
    INTERACTION_PARTICIPANT( 13 ),
    INTERFACE( 5 ),
    INTERFACE_REFERENCE( 19 ),
    MESSAGE( 16 ),
    PACKAGE( 6 ),
    PORT( 7 ),
    SATISFACTION( 21 ),
    TIME_SPAN( 14 ),
    TIMING_MARK( 12 ),
    USE_CASE_ASSOCIATION( 15 );

    private final int value;

    ElementTypeConstants() {
        value = -1;
    }

    ElementTypeConstants( int value ) {
        this.value = value;
    }

    public int getValue() {
        return value;
    }

    @Override
    public boolean equality( ElementTypeConstants value ) throws XtumlException {
        return null != value && this.value == value.getValue();
    }

    @Override
    public ElementTypeConstants value() {
        return this;
    }

    @Override
    public String serialize() {
        return Integer.toString(value);
    }

    public static ElementTypeConstants deserialize(Object o) throws XtumlException {
        if (o instanceof ElementTypeConstants) {
            return (ElementTypeConstants)o;
        }
        else {
            int value;
            if (o instanceof Integer) {
                value = (int)o;
            }
            else if (o instanceof String) {
                value = Integer.parseInt((String)o);
            }
            else throw new XtumlException("Cannot deserialize value");
            return valueOf(value);
        }
    }

    public static ElementTypeConstants valueOf(int value) {
        switch( value ) {
        case 11:
            return ACTIVITY_EDGE;
        case 17:
            return ACTIVITY_NODE;
        case 10:
            return ACTIVITY_PARTITION;
        case 8:
            return ASSOCIATION;
        case 1:
            return CLASS;
        case 3:
            return COMPONENT;
        case 20:
            return COMPONENT_REFERENCE;
        case 9:
            return CONSTANT;
        case 2:
            return DATATYPE;
        case 22:
            return DELEGATION;
        case 4:
            return EE;
        case 23:
            return EXCEPTION;
        case 0:
            return FUNCTION;
        case 18:
            return IMPORTED_CLASS;
        case 13:
            return INTERACTION_PARTICIPANT;
        case 5:
            return INTERFACE;
        case 19:
            return INTERFACE_REFERENCE;
        case 16:
            return MESSAGE;
        case 6:
            return PACKAGE;
        case 7:
            return PORT;
        case 21:
            return SATISFACTION;
        case 14:
            return TIME_SPAN;
        case 12:
            return TIMING_MARK;
        case 15:
            return USE_CASE_ASSOCIATION;
        default:
            return UNINITIALIZED_ENUM;
        }
    }

}

==> tool-sql-2.3.1-sources.jar: ooaofooa/datatypes/ElementTypeConstants.java <==
package ooaofooa.datatypes;


import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.IXtumlType;

import java.util.regex.Matcher;
import java.util.regex.Pattern;


public enum ElementTypeConstants implements IXtumlType {

    UNINITIALIZED_ENUM( -1 ),
    ACTIVITY_EDGE( 11 ),
    ACTIVITY_NODE( 17 ),
    ACTIVITY_PARTITION( 10 ),
    ASSOCIATION( 8 ),
    CLASS( 1 ),
    COMPONENT( 3 ),
    COMPONENT_REFERENCE( 20 ),
    CONSTANT( 9 ),
    DATATYPE( 2 ),
    DELEGATION( 22 ),
    EE( 4 ),
    EXCEPTION( 23 ),
    FUNCTION( 0 ),
    IMPORTED_CLASS( 18 ),
    INTERACTION_PARTICIPANT( 13 ),
    INTERFACE( 5 ),
    INTERFACE_REFERENCE( 19 ),
    MESSAGE( 16 ),
    PACKAGE( 6 ),
    PORT( 7 ),
    SATISFACTION( 21 ),
    TIME_SPAN( 14 ),
    TIMING_MARK( 12 ),
    USE_CASE_ASSOCIATION( 15 );

    private final int value;

    ElementTypeConstants() {
        value = -1;
    }

    ElementTypeConstants( int value ) {
        this.value = value;
    }

    public int getValue() {
        return value;
    }

    @Override
    public boolean equality( IXtumlType value ) throws XtumlException {
        if (value instanceof ElementTypeConstants) {
            return null != value && this.value == ((ElementTypeConstants)value).getValue();
        }
        else return false;
    }

    @Override
    public String serialize() {
        return Integer.toString(value);
    }

    public static ElementTypeConstants deserialize(Object o) throws XtumlException {
        if (o instanceof ElementTypeConstants) {
            return (ElementTypeConstants)o;
        }
        else if (o instanceof Integer) {
            return valueOf((int)o);
        }
        else if (o instanceof String) {
            try {
                return valueOf(Integer.parseInt((String)o));
            }
            catch (NumberFormatException e1) {
                Matcher m = Pattern.compile("([A-Za-z_]+)::([A-Za-z_]+)").matcher((String)o);
                if (m.matches() && "elementtypeconstants".equals(m.group(1).toLowerCase())) {
                    try {
                        return Enum.valueOf(ElementTypeConstants.class, m.group(2).toUpperCase());
                    } catch (IllegalArgumentException e2) {/* do nothing */}
                }
            }
        }
        throw new XtumlException("Cannot deserialize value");
    }

    public static ElementTypeConstants valueOf(int value) {
        switch( value ) {
        case 11:
            return ACTIVITY_EDGE;
        case 17:
            return ACTIVITY_NODE;
        case 10:
            return ACTIVITY_PARTITION;
        case 8:
            return ASSOCIATION;
        case 1:
            return CLASS;
        case 3:
            return COMPONENT;
        case 20:
            return COMPONENT_REFERENCE;
        case 9:
            return CONSTANT;
        case 2:
            return DATATYPE;
        case 22:
            return DELEGATION;
        case 4:
            return EE;
        case 23:
            return EXCEPTION;
        case 0:
            return FUNCTION;
        case 18:
            return IMPORTED_CLASS;
        case 13:
            return INTERACTION_PARTICIPANT;
        case 5:
            return INTERFACE;
        case 19:
            return INTERFACE_REFERENCE;
        case 16:
            return MESSAGE;
        case 6:
            return PACKAGE;
        case 7:
            return PORT;
        case 21:
            return SATISFACTION;
        case 14:
            return TIME_SPAN;
        case 12:
            return TIMING_MARK;
        case 15:
            return USE_CASE_ASSOCIATION;
        default:
            return UNINITIALIZED_ENUM;
        }
    }

}
